@@ -5,17 +5,18 @@ use utf8;
 
 package Neo4j::Driver::Transport::HTTP;
 # ABSTRACT: Adapter for the Neo4j Transactional HTTP API
-$Neo4j::Driver::Transport::HTTP::VERSION = '0.16';
+$Neo4j::Driver::Transport::HTTP::VERSION = '0.17';
 
 use Carp qw(carp croak);
 our @CARP_NOT = qw(Neo4j::Driver::Transaction);
 use Try::Tiny;
 
-use URI 1.25;
+use URI 1.31;
 use REST::Client 134;
-use JSON::MaybeXS 1.002004 qw(JSON);
+use JSON::MaybeXS 1.003003 qw();
 
 use Neo4j::Driver::ResultSummary;
+use Neo4j::Driver::ServerInfo;
 use Neo4j::Driver::StatementResult;
 
 
@@ -24,19 +25,10 @@ BEGIN { $JSON_CODER = sub {
 	return JSON::MaybeXS->new(utf8 => 1, allow_nonref => 0);
 }}
 
-our %ENDPOINTS_NEO4J_3 = (  # https://neo4j.com/docs/http-api/3.5/
-	new_transaction => '/db/data/transaction',
-	new_commit => '/db/data/transaction/commit',
-);
-our %ENDPOINTS_NEO4J_4 = (  # https://neo4j.com/docs/http-api/4.0/
-	new_transaction => '/db/{databaseName}/tx',
-	new_commit => '/db/{databaseName}/tx/commit',
-);
-
 our $CONTENT_TYPE = 'application/json';
 
-# https://neo4j.com/docs/rest-docs/current/#rest-api-service-root
-our $SERVICE_ROOT_ENDPOINT = '/db/data/';
+our $DISCOVERY_ENDPOINT = '/';
+our $COMMIT_ENDPOINT = 'commit';
 
 # use 'rest' in place of broken 'meta', see neo4j #12306
 our $RESULT_DATA_CONTENTS = ['row', 'rest'];
@@ -52,7 +44,6 @@ sub new {
 		die_on_error => $driver->{die_on_error},
 		cypher_types => $driver->{cypher_types},
 		cypher_filter => $driver->{cypher_filter},
-		endpoints => \%ENDPOINTS_NEO4J_3,
 	}, $class;
 	
 	my $uri = $driver->{uri};
@@ -69,6 +60,7 @@ sub new {
 	});
 	if ($uri->scheme eq 'https') {
 		$client->setCa($driver->{tls_ca});
+		croak "TLS CA file '$driver->{tls_ca}' doesn't exist (or is not a plain file)" if defined $driver->{tls_ca} && ! -f $driver->{tls_ca};  # REST::Client 273 doesn't support symbolic links
 		croak "HTTPS does not support unencrypted communication; use HTTP" if defined $driver->{tls} && ! $driver->{tls};
 	}
 	else {
@@ -87,13 +79,56 @@ sub new {
 }
 
 
-# Switch to using the specified database (Neo4j >= 4 only).
-sub _database {
-	my ($self, $db) = @_;
+# Use the REST service discovery API to obtain ServerInfo and the
+# correct endpoints depending on the server version.
+sub _connect {
+	my ($self, $database) = @_;
 	
-	$self->{endpoints} = { %ENDPOINTS_NEO4J_4 };
-	$self->{endpoints}->{new_transaction} =~ s/{databaseName}/$db/;
-	$self->{endpoints}->{new_commit} =~ s/{databaseName}/$db/;
+	my ($neo4j_version, $tx_endpoint);
+	my @discovery_queue = ($DISCOVERY_ENDPOINT);
+	while (@discovery_queue) {
+		my $tx = { transaction_endpoint => shift @discovery_queue };
+		my $service = $self->_request($tx, 'GET');
+		
+		$neo4j_version = $service->{neo4j_version};
+		$tx_endpoint = $service->{transaction};
+		last if $neo4j_version && $tx_endpoint;
+		
+		# a different discovery endpoint existed in Neo4j < 4.0
+		if ($service->{data}) {
+			push @discovery_queue, URI->new( $service->{data} )->path;
+		}
+	}
+	
+	croak "Neo4j server not found (ServerInfo discovery failed)" unless $neo4j_version && $tx_endpoint;
+	
+	$self->{server_info} = Neo4j::Driver::ServerInfo->new({
+		uri => $self->{client}->getHost(),
+		version => "Neo4j/$neo4j_version",
+	});
+	
+	if ($neo4j_version !~ m{^[23]\.}) {
+		if (! defined $database) {
+			# discover default database on Neo4j >= 4
+			eval {
+				my $endpoint = "$tx_endpoint/$COMMIT_ENDPOINT";
+				$endpoint =~ s/{databaseName}/system/;
+				my ($result) = $self->run(
+					{ transaction_endpoint => URI->new( $endpoint )->path },
+					{ statement => 'SHOW DEFAULT DATABASE', resultDataContents => $RESULT_DATA_CONTENTS },
+				);
+				$database = $result->single->get('name');
+			};
+			croak $@ . "The default database could not be determined" unless defined $database;
+		}
+		$database = URI::Escape::uri_escape_utf8 $database;
+		$tx_endpoint =~ s/{databaseName}/$database/;
+	}
+	
+	$self->{endpoints} = {
+		new_transaction => "$tx_endpoint",
+		new_commit => "$tx_endpoint/$COMMIT_ENDPOINT",
+	};
 }
 
 
@@ -114,7 +149,7 @@ sub prepare {
 	my $json = { statement => '' . $query };
 	$json->{resultDataContents} = $RESULT_DATA_CONTENTS;
 	$json->{resultDataContents} = $RESULT_DATA_CONTENTS_GRAPH if $self->{return_graph};
-	$json->{includeStats} = JSON()->true if $self->{return_stats};
+	$json->{includeStats} = \1 if $self->{return_stats};
 	$json->{parameters} = $parameters if defined $parameters;
 	
 	return $json;
@@ -145,6 +180,7 @@ sub run {
 			deep_bless => \&_deep_bless,
 			detach_stream => $detach_stream,
 			cypher_types => $self->{cypher_types},
+			server_info => $self->{server_info},
 		});
 	}
 	return @results;
@@ -157,7 +193,7 @@ sub _request {
 	my $client = $self->{client};
 	
 	my $tx_endpoint = $tx->{transaction_endpoint};
-	$tx_endpoint //= URI->new( $self->{endpoints}->{new_transaction} );
+	$tx_endpoint //= URI->new( $self->{endpoints}->{new_transaction} )->path;
 	$client->request( $method, "$tx_endpoint", $content );
 	
 	my $content_type = $client->responseHeader('Content-Type');
@@ -217,7 +253,7 @@ sub autocommit {
 	my ($self, $tx) = @_;
 	
 	$tx->{transaction_endpoint} = $tx->{commit_endpoint};
-	$tx->{transaction_endpoint} //= URI->new( $self->{endpoints}->{new_commit} );
+	$tx->{transaction_endpoint} //= URI->new( $self->{endpoints}->{new_commit} )->path;
 }
 
 
@@ -234,8 +270,7 @@ sub commit {
 sub rollback {
 	my ($self, $tx) = @_;
 	
-	# Explicitly marking this transaction as closed by removing the commit
-	# URL is only necessary for transactions that never have been used.
+	# Transactions that never have been used have no endpoint of their own.
 	# These would initially contact the server's root transaction endpoint,
 	# DELETE'ing which fails (as it should). But calling rollback on an
 	# open transaction should never fail. Hence we need to special-case
@@ -244,33 +279,6 @@ sub rollback {
 }
 
 
-sub server_info {
-	my ($self) = @_;
-	
-	# That the ServerInfo is provided by the same object
-	# is an implementation detail that might change in future.
-	return $self;
-}
-
-
-# server_info->
-sub address {
-	my ($self) = @_;
-	
-	return URI->new( $self->{client}->getHost() )->host_port;
-}
-
-
-# server_info->
-sub version {
-	my ($self) = @_;
-	
-	foreach my $endpoint ( '/', $SERVICE_ROOT_ENDPOINT ) {
-		my $json = $self->{client}->GET( $endpoint )->responseContent();
-		my $neo4j_version = $self->{json_coder}->decode($json)->{neo4j_version};
-		return "Neo4j/$neo4j_version" if $neo4j_version;
-	}
-}
 
 
 sub _deep_bless {
@@ -278,14 +286,14 @@ sub _deep_bless {
 	
 	# "meta" is broken, so we primarily use "rest", see neo4j #12306
 	
-	if (ref $data eq 'HASH' && ref $rest eq 'HASH' && ref $rest->{metadata} eq 'HASH' && $rest->{self} && $rest->{self} =~ m|/db/data/node/|) {  # node
+	if (ref $data eq 'HASH' && ref $rest eq 'HASH' && ref $rest->{metadata} eq 'HASH' && $rest->{self} && $rest->{self} =~ m|/db/[^/]+/node/|) {  # node
 		bless $data, $cypher_types->{node};
 		$data->{_meta} = $rest->{metadata};
 		$data->{_meta}->{deleted} = $meta->{deleted} if ref $meta eq 'HASH';
 		$cypher_types->{init}->($data) if $cypher_types->{init};
 		return $data;
 	}
-	if (ref $data eq 'HASH' && ref $rest eq 'HASH' && ref $rest->{metadata} eq 'HASH' && $rest->{self} && $rest->{self} =~ m|/db/data/relationship/|) {  # relationship
+	if (ref $data eq 'HASH' && ref $rest eq 'HASH' && ref $rest->{metadata} eq 'HASH' && $rest->{self} && $rest->{self} =~ m|/db/[^/]+/relationship/|) {  # relationship
 		bless $data, $cypher_types->{relationship};
 		$data->{_meta} = $rest->{metadata};
 		$rest->{start} =~ m|/([0-9]+)$|;
@@ -377,7 +385,7 @@ Neo4j::Driver::Transport::HTTP - Adapter for the Neo4j Transactional HTTP API
 
 =head1 VERSION
 
-version 0.16
+version 0.17
 
 =head1 DESCRIPTION
 
